==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QStringConverterBase_State_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qstringconverter_base.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStringConverterBase_State(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStringConverterBase::State")
    QStringConverterBase::State *_ptr = reinterpret_cast<QStringConverterBase::State *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new State(QStringConverterBase::Flags)
void __qt_construct_QStringConverterBase_State_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct State(QStringConverterBase::Flags)")
    Q_UNUSED(__java_arguments)
    QStringConverterBase::State *__qt_this = new(__qtjambi_ptr) QStringConverterBase::State();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new State(QStringConverterBase::Flags)
void __qt_construct_QStringConverterBase_State_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct State(QStringConverterBase::Flags)")
    jobject f0 = __java_arguments[0].l;
    QStringConverterBase::Flags __qt_f0 = qtjambi_cast<QStringConverterBase::Flags>(__jni_env, f0);
    QStringConverterBase::State *__qt_this = new(__qtjambi_ptr) QStringConverterBase::State(QStringConverterBase::Flags(__qt_f0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QStringConverterBase::State
void __qt_destruct_QStringConverterBase_State(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStringConverterBase::State")
    reinterpret_cast<QStringConverterBase::State*>(ptr)->~State();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStringConverterBase::State::State(QStringConverterBase::Flags)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_initialize_1native__Lio_qt_core_QStringConverterBase_00024State_2Lio_qt_core_QStringConverterBase_00024Flags_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject f0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStringConverterBase::State::State(QStringConverterBase::Flags)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = f0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStringConverterBase_State_1, sizeof(QStringConverterBase::State), typeid(QStringConverterBase::State), false, &deleter_QStringConverterBase_State, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_setFlags_1native_1cref_1QStringConverterBase_1Flags__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint flags0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QStringConverterBase::Flags __qt_flags0 = qtjambi_cast<QStringConverterBase::Flags>(__jni_env, flags0);
        __qt_this->flags = QStringConverterBase::Flags(__qt_flags0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_flags_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QStringConverterBase::Flags&  __qt_value = __qt_this->flags;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_setInternalState_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint internalState0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->internalState = static_cast<int>(internalState0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_internalState_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->internalState;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_setInvalidChars_1native_1qsizetype__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong invalidChars0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->invalidChars = static_cast<qsizetype>(invalidChars0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_invalidChars_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qsizetype  __qt_value = __qt_this->invalidChars;
        __java_return_value = jlong(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_setRemainingChars_1native_1qsizetype__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong remainingChars0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->remainingChars = static_cast<qsizetype>(remainingChars0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_remainingChars_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qsizetype  __qt_value = __qt_this->remainingChars;
        __java_return_value = jlong(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QStringConverterBase_State(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QStringConverterBase::State>("QStringConverterBase::State", "io/qt/core/QStringConverterBase$State");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStringConverterBase_State, {
        ConstructorInfo(&__qt_construct_QStringConverterBase_State_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QStringConverterBase_State_1, "Lio/qt/core/QStringConverterBase$Flags;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStringConverterBase_State);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QStringConverterBase_State_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qstringconverter_base.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStringConverterBase_State(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStringConverterBase::State")
    QStringConverterBase::State *_ptr = reinterpret_cast<QStringConverterBase::State *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new State(QStringConverterBase::Flags)
void __qt_construct_QStringConverterBase_State(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct State(QStringConverterBase::Flags)")
    Q_UNUSED(__java_arguments)
    QStringConverterBase::State *__qt_this = new(__qtjambi_ptr) QStringConverterBase::State();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new State(QStringConverterBase::Flags)
void __qt_construct_QStringConverterBase_State_QStringConverterBase_Flags(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct State(QStringConverterBase::Flags)")
    jobject f0 = __java_arguments[0].l;
    QStringConverterBase::Flags __qt_f0 = qtjambi_cast<QStringConverterBase::Flags>(__jni_env, f0);
    QStringConverterBase::State *__qt_this = new(__qtjambi_ptr) QStringConverterBase::State(QStringConverterBase::Flags(__qt_f0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QStringConverterBase::State::State(QStringConverterBase::Flags)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_initialize_1native__Lio_qt_core_QStringConverterBase_00024State_2Lio_qt_core_QStringConverterBase_00024Flags_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject f0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStringConverterBase::State::State(QStringConverterBase::Flags)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = f0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStringConverterBase_State_QStringConverterBase_Flags, sizeof(QStringConverterBase::State), typeid(QStringConverterBase::State), false, &deleter_QStringConverterBase_State, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStringConverterBase::State
void __qt_destruct_QStringConverterBase_State(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStringConverterBase::State")
    reinterpret_cast<QStringConverterBase::State*>(ptr)->~State();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_setFlags_1native_1cref_1QStringConverterBase_1Flags__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint flags0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QStringConverterBase::Flags __qt_flags0 = qtjambi_cast<QStringConverterBase::Flags>(__jni_env, flags0);
        __qt_this->flags = QStringConverterBase::Flags(__qt_flags0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_flags_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QStringConverterBase::Flags&  __qt_value = __qt_this->flags;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_setInternalState_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint internalState0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->internalState = static_cast<int>(internalState0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_internalState_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->internalState;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_setInvalidChars_1native_1qsizetype__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong invalidChars0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->invalidChars = static_cast<qsizetype>(invalidChars0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_invalidChars_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qsizetype  __qt_value = __qt_this->invalidChars;
        __java_return_value = jlong(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_setRemainingChars_1native_1qsizetype__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong remainingChars0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->remainingChars = static_cast<qsizetype>(remainingChars0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStringConverterBase_00024State_remainingChars_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStringConverterBase::State *__qt_this = QtJambiAPI::objectFromNativeId<QStringConverterBase::State>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qsizetype  __qt_value = __qt_this->remainingChars;
        __java_return_value = jlong(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QStringConverterBase_State(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QStringConverterBase::State>("QStringConverterBase::State", "io/qt/core/QStringConverterBase$State");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStringConverterBase_State, {
        ConstructorInfo(&__qt_construct_QStringConverterBase_State, nullptr)
       ,ConstructorInfo(&__qt_construct_QStringConverterBase_State_QStringConverterBase_Flags, "Lio/qt/core/QStringConverterBase$Flags;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStringConverterBase_State);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
